@@ -72,12 +72,14 @@ var group__spa__loop =
     [ "SPA_VERSION_LOOP_CONTROL_METHODS", "group__spa__loop.html#ga2b1b3decfe2f7f50d690dba084a6f83e", null ],
     [ "spa_loop_control_method_v", "group__spa__loop.html#ga0f531ff1357bf1f6ad225faa1f99b265", null ],
     [ "spa_loop_control_method_r", "group__spa__loop.html#ga4b23dfd9d8eadc0364b62ff9bdc25e82", null ],
+    [ "spa_loop_control_method_fast_r", "group__spa__loop.html#ga4ee9dd3d66c0bf6f35837e150c59ccc2", null ],
     [ "spa_loop_control_get_fd", "group__spa__loop.html#gab1b169d1e380c8af23a07c8b149139df", null ],
     [ "spa_loop_control_add_hook", "group__spa__loop.html#gaffe08d7788d04fa44c44fda7ab3649bb", null ],
     [ "spa_loop_control_enter", "group__spa__loop.html#ga32dfd8283bd79d057fefb94a7e1f653c", null ],
     [ "spa_loop_control_leave", "group__spa__loop.html#ga3ab19534c467fdf6055e1db9a2144e9b", null ],
     [ "spa_loop_control_iterate", "group__spa__loop.html#ga3bae0b32100f5752b3372a505c8e04f6", null ],
     [ "spa_loop_control_check", "group__spa__loop.html#gafdc6876cd766fafc297841accedcd105", null ],
+    [ "spa_loop_control_iterate_fast", "group__spa__loop.html#gaa4db60dd6841e3c590446307fb16ea36", null ],
     [ "SPA_VERSION_LOOP_UTILS_METHODS", "group__spa__loop.html#ga3b9f5ee85f8290ef943a23ceaf5181eb", null ],
     [ "spa_loop_utils_method_v", "group__spa__loop.html#ga48a9f2265639949de21d784ca415ecc7", null ],
     [ "spa_loop_utils_method_r", "group__spa__loop.html#gad5742d5525667f7c2287e73ec46df0e1", null ],
