@@ -63,27 +63,28 @@ var NAVTREEINDEX =
 [
 "alloc_8h.html",
 "group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
-"group__pw__global.html#gab6796dae933803798be1658f4020315c",
-"group__pw__keys.html#gaa039c0a911742213e239311ec73b623b",
-"group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f",
-"group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219",
-"group__pwtest.html#ga135297caa69f5e14b2b20148850d080b",
-"group__spa__cpu.html#gad4c6b81675ec1a16c23239041970f099",
-"group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64",
-"group__spa__names.html#gadc887e81536271d1538500da0fb6be1f",
-"group__spa__param.html#ga49c3cb2109aab971f92dfe13bde3759b",
-"group__spa__param.html#gga3338e5f0867a0e073d8dcfd309fe8850a682778cce4e3c92fa38ba77e8f838246",
-"group__spa__param.html#gga9c37ad62772233835d6bf5083a9e4613a3c01bfb4218e827d2d2f21385d71798e",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eaa9b46794cf9585c21b7880d238ce2355",
-"group__spa__pod.html#gab23072b3f0f817478e011658b3504161",
-"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84",
-"page_module_roc_sink.html",
-"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254",
-"structpw__impl__link__events.html",
-"structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97",
-"structspa__device__events.html#a5b83e45fd5922657978cc36df24cc1c7",
-"structspa__loop__utils__methods.html#adc8b3b97121c94a824307117dad02989",
-"structspa__strbuf.html#ad1ee23ef60728cefba6d11341da61ef1"
+"group__pw__global.html#ga5a70a0e4be433825f0e5baf7277c0e7e",
+"group__pw__keys.html#ga8226b0005fed53b77740e919947f6e60",
+"group__pw__module.html#gad670c8d581f68d016f475c12cff250c8",
+"group__pw__resource.html#gafc12935cd9ee93e992cae1e2910e6f04",
+"group__pw__utils.html#ga8869815cdd42998571019730afd248ff",
+"group__spa__cpu.html#ga863ee498bc3630a98ee12fe569a9dc30",
+"group__spa__interfaces.html#ga6492da0e834e92dbbcef7dd3026ce04f",
+"group__spa__names.html#ga4ca9373715177f903a0014796b1d8821",
+"group__spa__param.html#ga304470cf722efd8b2b0617268235c322",
+"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586add5a25402d5f44adde274c95091135d2",
+"group__spa__param.html#gga741ca54fc7f93308779660120bbed31eaa5d835e17315a1ed31a73323da1fa02a",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea43dce82d44b02558ba417caccf9395da",
+"group__spa__pod.html#ga9382aceb62c82555c3e3223fa0da4d16",
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a6b256812f3b819d23d240f76d70e2dbf",
+"page_midi.html#autotoc_md21",
+"page_spa_plugins.html#autotoc_md232",
+"structpw__core__events.html#a7e1a9d6c8598cee58b622cf61432769e",
+"structpw__link__info.html#a0c7b378ed65b5311702cd2b693d6b819",
+"structpw__time.html#a92d7a1849d4dc044d2fa64bd35a7a57d",
+"structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0",
+"structspa__node__methods.html#a3d23d14b7707fc2f3926a78d47dde720",
+"structspa__video__info__dsp.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
