@@ -150,7 +150,7 @@ var page_pipewire =
     ] ],
     [ "Graph Scheduling", "page_scheduling.html", [
       [ "Nodes", "page_scheduling.html#autotoc_md108", null ],
-      [ "links.", "page_scheduling.html#autotoc_md109", null ],
+      [ "Links", "page_scheduling.html#autotoc_md109", null ],
       [ "Drivers", "page_scheduling.html#autotoc_md110", [
         [ "Scheduling node A", "page_scheduling.html#autotoc_md111", null ],
         [ "Scheduling node B", "page_scheduling.html#autotoc_md112", null ],
